@@ -26,15 +26,15 @@ from .version import date as __date__
 import re
 import sys
 
-# import matplotlib.pyplot as plt
+import matplotlib.pyplot as plt
 import numpy as np
 
-# import pyvista
+import pyvista
 import prettytable
 import spglib
 
 from mechelastic.parsers import VaspOutcar
-from mechelastic.parsers import AbinitParser
+from mechelastic.parsers import AbinitOutput
 from mechelastic.comms import printer
 from mechelastic.core import Structure, ElasticProperties, ElasticProperties2D, ELATE
 from mechelastic.tests import ductile, eigenvals, stability, symmetry
