@@ -2,11 +2,14 @@
 
 from .comms import printer
 from .parsers import VaspOutcar
+from .parsers import AbinitOutput
 from .core import ElasticProperties
 from .core import ElasticProperties2D
 
 
-def calculate_elastic(infile="OUTCAR", dim="3D", crystal=None, code="vasp"):
+def calculate_elastic(
+    infile="OUTCAR", dim="3D", crystal=None, code="vasp", ddbfile=None
+):
 
     """
     This method calculates the elastic properties
@@ -28,6 +31,12 @@ def calculate_elastic(infile="OUTCAR", dim="3D", crystal=None, code="vasp"):
         structure = output.structure
         lattice_constant = output.lattice_constant
 
+    elif code == "abinit":
+        output = AbinitOutput(infile=infile, ddbfile=ddbfile)
+        elastic_tensor = output.elastic_tensor
+        structure = output.structure
+        lattice_constant = output.lattice_constant
+
     # elastic constants calculation for 3D materials
     if dim == "3D":
         elastic_properties = ElasticProperties(elastic_tensor, structure, crystal_type)
